@@ -4,7 +4,7 @@
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     03.04.98
-// RCS-ID:      $Id: regtest.cpp,v 1.22 2004/10/02 12:35:39 VS Exp $
+// RCS-ID:      $Id: regtest.cpp,v 1.23 2005/05/23 10:48:27 ABX Exp $
 // Copyright:   (c) 1998 Vadim Zeitlin <zeitlin@dptmaths.ens-cachan.fr>
 // Licence:     wxWindows license
 ///////////////////////////////////////////////////////////////////////////////
@@ -964,7 +964,7 @@ bool RegTreeCtrl::TreeNode::OnExpand()
     while ( bCont )
     {
         wxString strItem;
-        if (str.IsEmpty())
+        if (str.empty())
             strItem = _T("<default>");
         else
             strItem = str;
