@@ -4,7 +4,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     29/01/98
-// RCS-ID:      $Id: filefn.cpp,v 1.240 2005/05/31 09:19:50 JS Exp $
+// RCS-ID:      $Id: filefn.cpp,v 1.249 2005/09/20 09:52:14 VZ Exp $
 // Copyright:   (c) 1998 Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -56,11 +56,6 @@
 
 #include "wx/log.h"
 
-// No, Cygwin doesn't appear to have fnmatch.h after all.
-#if defined(HAVE_FNMATCH_H)
-    #include "fnmatch.h"
-#endif
-
 #ifdef __WINDOWS__
     #include "wx/msw/private.h"
     #include "wx/msw/mslu.h"
@@ -172,7 +167,7 @@ void wxPathList::Add (const wxString& path)
 }
 
 // Add paths e.g. from the PATH environment variable
-void wxPathList::AddEnvList (const wxString& envVariable)
+void wxPathList::AddEnvList (const wxString& WXUNUSED_IN_WINCE(envVariable))
 {
     // No environment variables on WinCE
 #ifndef __WXWINCE__
@@ -189,7 +184,7 @@ void wxPathList::AddEnvList (const wxString& envVariable)
         wxT(" :;");
 #endif
 
-    wxString val ;    
+    wxString val ;
     if (wxGetEnv (WXSTRINGCAST envVariable, &val))
     {
         wxChar *s = MYcopystring (val);
@@ -214,9 +209,7 @@ void wxPathList::AddEnvList (const wxString& envVariable)
 
         delete [] s;
     }
-#else // __WXWINCE__
-    wxUnusedVar(envVariable);
-#endif // !__WXWINCE__/__WXWINCE__
+#endif // !__WXWINCE__
 }
 
 // Given a full filename (with path), ensure that that file can
@@ -360,17 +353,17 @@ wxIsAbsolutePath (const wxString& filename)
 
 void wxStripExtension(wxChar *buffer)
 {
-  int len = wxStrlen(buffer);
-  int i = len-1;
-  while (i > 0)
-  {
-    if (buffer[i] == wxT('.'))
+    int len = wxStrlen(buffer);
+    int i = len-1;
+    while (i > 0)
     {
-      buffer[i] = 0;
-      break;
+        if (buffer[i] == wxT('.'))
+        {
+            buffer[i] = 0;
+            break;
+        }
+        i --;
     }
-    i --;
-  }
 }
 
 void wxStripExtension(wxString& buffer)
@@ -553,7 +546,7 @@ wxChar *wxExpandPath(wxChar *buf, const wxChar *name)
     while ((*d++ = *s) != 0) {
 #  ifndef __WXMSW__
         if (*s == wxT('\\')) {
-            if ((*(d - 1) = *++s)) {
+            if ((*(d - 1) = *++s)!=0) {
                 s++;
                 continue;
             } else
@@ -619,11 +612,14 @@ wxChar *wxExpandPath(wxChar *buf, const wxChar *name)
             nnm = *s ? s + 1 : s;
             *s = 0;
         // FIXME: wxGetUserHome could return temporary storage in Unicode mode
-            if ((home = WXSTRINGCAST wxGetUserHome(wxString(nm + 1))) == NULL) {
-               if (was_sep) /* replace only if it was there: */
-                   *s = SEP;
+            if ((home = WXSTRINGCAST wxGetUserHome(wxString(nm + 1))) == NULL)
+            {
+                if (was_sep) /* replace only if it was there: */
+                    *s = SEP;
                 s = NULL;
-            } else {
+            }
+            else
+            {
                 nm = nnm;
                 s = home;
             }
@@ -657,7 +653,9 @@ wxChar *wxExpandPath(wxChar *buf, const wxChar *name)
    The call wxExpandPath can convert these back!
  */
 wxChar *
-wxContractPath (const wxString& filename, const wxString& envname, const wxString& user)
+wxContractPath (const wxString& filename,
+                const wxString& WXUNUSED_IN_WINCE(envname),
+                const wxString& user)
 {
   static wxChar dest[_MAXPATHLEN];
 
@@ -683,8 +681,6 @@ wxContractPath (const wxString& filename, const wxString& envname, const wxStrin
         wxStrcat (tcp, wxT("}"));
         wxStrcat (tcp, wxFileFunctionsBuffer);
     }
-#else
-  wxUnusedVar(envname);
 #endif
 
   // Handle User's home (ignore root homes!)
@@ -959,39 +955,38 @@ wxUnix2DosFilename (wxChar *WXUNUSED(s) )
 bool
 wxConcatFiles (const wxString& file1, const wxString& file2, const wxString& file3)
 {
-  wxString outfile;
-  if ( !wxGetTempFileName( wxT("cat"), outfile) )
-      return false;
+#if wxUSE_FILE
 
-  FILE *fp1 wxDUMMY_INITIALIZE(NULL);
-  FILE *fp2 = NULL;
-  FILE *fp3 = NULL;
-  // Open the inputs and outputs
-  if ((fp1 = wxFopen ( file1, wxT("rb"))) == NULL ||
-      (fp2 = wxFopen ( file2, wxT("rb"))) == NULL ||
-      (fp3 = wxFopen ( outfile, wxT("wb"))) == NULL)
+    wxFile in1(file1), in2(file2);
+    wxTempFile out(file3);
+
+    if ( !in1.IsOpened() || !in2.IsOpened() || !out.IsOpened() )
+        return false;
+
+    ssize_t ofs;
+    unsigned char buf[1024];
+
+    for( int i=0; i<2; i++)
     {
-      if (fp1)
-        fclose (fp1);
-      if (fp2)
-        fclose (fp2);
-      if (fp3)
-        fclose (fp3);
-      return false;
+        wxFile *in = i==0 ? &in1 : &in2;
+        do{
+            if ( (ofs = in->Read(buf,WXSIZEOF(buf))) == wxInvalidOffset ) return false;
+            if ( ofs > 0 )
+                if ( !out.Write(buf,ofs) )
+                    return false;
+        } while ( ofs == (ssize_t)WXSIZEOF(buf) );
     }
 
-  int ch;
-  while ((ch = getc (fp1)) != EOF)
-    (void) putc (ch, fp3);
-  fclose (fp1);
+    return out.Commit();
 
-  while ((ch = getc (fp2)) != EOF)
-    (void) putc (ch, fp3);
-  fclose (fp2);
+#else
 
-  fclose (fp3);
-  bool result = wxRenameFile(outfile, file3);
-  return result;
+    wxUnusedVar(file1);
+    wxUnusedVar(file2);
+    wxUnusedVar(file3);
+    return false;
+
+#endif
 }
 
 // Copy files
@@ -1159,6 +1154,7 @@ bool wxMkdir(const wxString& dir, int perm)
     if ( mkdir(wxFNCONV(dirname), perm) != 0 )
   #endif
 #elif defined(__OS2__)
+    wxUnusedVar(perm);
     if (::DosCreateDir((PSZ)dirname, NULL) != 0) // enhance for EAB's??
 #elif defined(__DOS__)
   #if defined(__WATCOMC__)
@@ -1236,7 +1232,7 @@ bool wxDirExists(const wxChar *pszPathName)
 
     return (ret != (DWORD)-1) && (ret & FILE_ATTRIBUTE_DIRECTORY);
 #elif defined(__OS2__)
-    return (::DosSetCurrentDir((PSZ)(WXSTRINGCAST strPath)));
+    return (bool)(::DosSetCurrentDir((PSZ)(WXSTRINGCAST strPath)));
 #else // !__WIN32__
 
     wxStructStat st;
@@ -1367,10 +1363,6 @@ wxChar *wxGetWorkingDirectory(wxChar *buf, int sz)
     bool needsANSI = true;
 
     #if !defined(HAVE_WGETCWD) || wxUSE_UNICODE_MSLU
-        // This is not legal code as the compiler
-        // is allowed destroy the wxCharBuffer.
-        // wxCharBuffer c_buffer(sz);
-        // char *cbuf = (char*)(const char*)c_buffer;
         char cbuf[_MAXPATHLEN];
     #endif
 
@@ -1414,7 +1406,7 @@ wxChar *wxGetWorkingDirectory(wxChar *buf, int sz)
                                       ,cbuf + 3
                                       ,(PULONG)&sz
                                      );
-            cbuf[0] = 'A' + (ulDriveNum - 1);
+            cbuf[0] = char('A' + (ulDriveNum - 1));
             cbuf[1] = ':';
             cbuf[2] = '\\';
             ok = rc == 0;
@@ -1456,7 +1448,13 @@ wxChar *wxGetWorkingDirectory(wxChar *buf, int sz)
 #if defined( __CYGWIN__ ) && defined( __WINDOWS__ )
         // another example of DOS/Unix mix (Cygwin)
         wxString pathUnix = buf;
+#if wxUSE_UNICODE
+        char bufA[_MAXPATHLEN];
+        cygwin_conv_to_full_win32_path(pathUnix.mb_str(wxConvFile), bufA);
+        wxConvFile.MB2WC(buf, bufA, sz);
+#else
         cygwin_conv_to_full_win32_path(pathUnix, buf);
+#endif // wxUSE_UNICODE
 #endif // __CYGWIN__
     }
 
@@ -1605,40 +1603,38 @@ time_t WXDLLEXPORT wxFileModificationTime(const wxString& filename)
 #if defined(__WXPALMOS__)
     return 0;
 #elif defined(__WXWINCE__)
-    FILETIME creationTime, lastAccessTime, lastWriteTime;
-    HANDLE fileHandle = ::CreateFile(filename, GENERIC_READ, FILE_SHARE_READ, NULL,
-        0, FILE_ATTRIBUTE_NORMAL, 0);
-    if (fileHandle == INVALID_HANDLE_VALUE)
+    FILETIME ftLastWrite;
+    AutoHANDLE hFile(::CreateFile(filename, GENERIC_READ, FILE_SHARE_READ,
+                                    NULL, 0, FILE_ATTRIBUTE_NORMAL, 0));
+
+    if ( !hFile.IsOk() )
         return 0;
-    else
+
+    if ( !::GetFileTime(hFile, NULL, NULL, &ftLastWrite) )
+        return 0;
+
+    // sure we want to translate to local time here?
+    FILETIME ftLocal;
+    if ( !::FileTimeToLocalFileTime(&ftLastWrite, &ftLocal) )
     {
-        if (GetFileTime(fileHandle, & creationTime, & lastAccessTime, & lastWriteTime))
-        {
-            CloseHandle(fileHandle);
-
-            wxDateTime dateTime;
-            FILETIME ftLocal;
-            if ( !::FileTimeToLocalFileTime(&lastWriteTime, &ftLocal) )
-            {
-                wxLogLastError(_T("FileTimeToLocalFileTime"));
-            }
-
-            SYSTEMTIME st;
-            if ( !::FileTimeToSystemTime(&ftLocal, &st) )
-            {
-                wxLogLastError(_T("FileTimeToSystemTime"));
-            }
-
-            dateTime.Set(st.wDay, wxDateTime::Month(st.wMonth - 1), st.wYear,
-                st.wHour, st.wMinute, st.wSecond, st.wMilliseconds);
-            return dateTime.GetTicks();
-        }
-        else
-            return 0;
+        wxLogLastError(_T("FileTimeToLocalFileTime"));
     }
+
+    // FILETIME is a counted in 100-ns since 1601-01-01, convert it to
+    // number of seconds since 1970-01-01
+    ULARGE_INTEGER uli;
+    uli.LowPart = ftLocal.dwLowDateTime;
+    uli.HighPart = ftLocal.dwHighDateTime;
+
+    ULONGLONG ull = uli.QuadPart;
+    ull /= wxULL(10000000);     // number of 100ns intervals in 1s
+    ull -= wxULL(11644473600);  // 1970-01-01 - 1601-01-01 in seconds
+
+    return wx_static_cast(time_t, ull);
 #else
     wxStructStat buf;
-    wxStat( filename, &buf);
+    if ( wxStat( filename, &buf) != 0 )
+        return 0;
 
     return buf.st_mtime;
 #endif
@@ -1649,7 +1645,9 @@ time_t WXDLLEXPORT wxFileModificationTime(const wxString& filename)
 // Returns 0 if none or if there's a problem.
 // filterStr is in the form: "All files (*.*)|*.*|JPEG Files (*.jpeg)|*.jpeg"
 
-int WXDLLEXPORT wxParseCommonDialogsFilter(const wxString& filterStr, wxArrayString& descriptions, wxArrayString& filters)
+int WXDLLEXPORT wxParseCommonDialogsFilter(const wxString& filterStr,
+                                           wxArrayString& descriptions,
+                                           wxArrayString& filters)
 {
     descriptions.Clear();
     filters.Clear();
@@ -1785,123 +1783,123 @@ bool wxIsWild( const wxString& pattern )
 
 bool wxMatchWild( const wxString& pat, const wxString& text, bool dot_special )
 {
-        if (text.empty())
+    if (text.empty())
+    {
+        /* Match if both are empty. */
+        return pat.empty();
+    }
+
+    const wxChar *m = pat.c_str(),
+    *n = text.c_str(),
+    *ma = NULL,
+    *na = NULL,
+    *mp = NULL,
+    *np = NULL;
+    int just = 0,
+    pcount = 0,
+    acount = 0,
+    count = 0;
+
+    if (dot_special && (*n == wxT('.')))
+    {
+        /* Never match so that hidden Unix files
+         * are never found. */
+        return false;
+    }
+
+    for (;;)
+    {
+        if (*m == wxT('*'))
         {
-                /* Match if both are empty. */
-                return pat.empty();
+            ma = ++m;
+            na = n;
+            just = 1;
+            mp = NULL;
+            acount = count;
         }
-
-        const wxChar *m = pat.c_str(),
-        *n = text.c_str(),
-        *ma = NULL,
-        *na = NULL,
-        *mp = NULL,
-        *np = NULL;
-        int just = 0,
-        pcount = 0,
-        acount = 0,
-        count = 0;
-
-        if (dot_special && (*n == wxT('.')))
+        else if (*m == wxT('?'))
         {
-                /* Never match so that hidden Unix files
-                 * are never found. */
+            m++;
+            if (!*n++)
                 return false;
         }
-
-        for (;;)
+        else
         {
-                if (*m == wxT('*'))
+            if (*m == wxT('\\'))
+            {
+                m++;
+                /* Quoting "nothing" is a bad thing */
+                if (!*m)
+                    return false;
+            }
+            if (!*m)
+            {
+                /*
+                * If we are out of both strings or we just
+                * saw a wildcard, then we can say we have a
+                * match
+                */
+                if (!*n)
+                    return true;
+                if (just)
+                    return true;
+                just = 0;
+                goto not_matched;
+            }
+            /*
+            * We could check for *n == NULL at this point, but
+            * since it's more common to have a character there,
+            * check to see if they match first (m and n) and
+            * then if they don't match, THEN we can check for
+            * the NULL of n
+            */
+            just = 0;
+            if (*m == *n)
+            {
+                m++;
+                if (*n == wxT(' '))
+                    mp = NULL;
+                count++;
+                n++;
+            }
+            else
+            {
+
+                not_matched:
+
+                /*
+                * If there are no more characters in the
+                * string, but we still need to find another
+                * character (*m != NULL), then it will be
+                * impossible to match it
+                */
+                if (!*n)
+                    return false;
+                if (mp)
                 {
-                        ma = ++m;
-                        na = n;
-                        just = 1;
+                    m = mp;
+                    if (*np == wxT(' '))
+                    {
                         mp = NULL;
-                        acount = count;
-                }
-                else if (*m == wxT('?'))
-                {
-                        m++;
-                        if (!*n++)
-                        return false;
+                        goto check_percent;
+                    }
+                    n = ++np;
+                    count = pcount;
                 }
                 else
+                check_percent:
+
+                if (ma)
                 {
-                        if (*m == wxT('\\'))
-                        {
-                                m++;
-                                /* Quoting "nothing" is a bad thing */
-                                if (!*m)
-                                return false;
-                        }
-                        if (!*m)
-                        {
-                                /*
-                                * If we are out of both strings or we just
-                                * saw a wildcard, then we can say we have a
-                                * match
-                                */
-                                if (!*n)
-                                return true;
-                                if (just)
-                                return true;
-                                just = 0;
-                                goto not_matched;
-                        }
-                        /*
-                        * We could check for *n == NULL at this point, but
-                        * since it's more common to have a character there,
-                        * check to see if they match first (m and n) and
-                        * then if they don't match, THEN we can check for
-                        * the NULL of n
-                        */
-                        just = 0;
-                        if (*m == *n)
-                        {
-                                m++;
-                                if (*n == wxT(' '))
-                                mp = NULL;
-                                count++;
-                                n++;
-                        }
-                        else
-                        {
-
-                                not_matched:
-
-                                /*
-                                * If there are no more characters in the
-                                * string, but we still need to find another
-                                * character (*m != NULL), then it will be
-                                * impossible to match it
-                                */
-                                if (!*n)
-                                return false;
-                                if (mp)
-                                {
-                                        m = mp;
-                                        if (*np == wxT(' '))
-                                        {
-                                                mp = NULL;
-                                                goto check_percent;
-                                        }
-                                        n = ++np;
-                                        count = pcount;
-                                }
-                                else
-                                check_percent:
-
-                                if (ma)
-                                {
-                                        m = ma;
-                                        n = ++na;
-                                        count = acount;
-                                }
-                                else
-                                return false;
-                        }
+                    m = ma;
+                    n = ++na;
+                    count = acount;
                 }
+                else
+                    return false;
+            }
         }
+    }
 }
 
 // Return the type of an open file
@@ -1972,7 +1970,7 @@ wxFileKind wxGetFileKind(FILE *fp)
     (void)fp;
     return wxFILE_KIND_DISK;
 #else
-    return wxGetFileKind(fileno(fp));
+    return fp ? wxGetFileKind(fileno(fp)) : wxFILE_KIND_UNKNOWN;
 #endif
 }
 
