@@ -4,7 +4,7 @@
 // Author:      Stefan Csomor
 // Modified by:
 // Created:     1998-01-01
-// RCS-ID:      $Id: clipbrd.cpp,v 1.36 2005/05/04 21:04:32 RD Exp $
+// RCS-ID:      $Id: clipbrd.cpp,v 1.38 2005/07/22 18:08:16 ABX Exp $
 // Copyright:   (c) Stefan Csomor
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -96,7 +96,12 @@ void *wxGetClipboardData(wxDataFormat dataFormat, long *len)
                     if ( dataFormat.GetType() == wxDF_TEXT )
                         ((char*)data)[byteCount] = 0 ;
                     if ( dataFormat.GetType() == wxDF_UNICODETEXT )
-                        ((wxChar*)data)[byteCount/2] = 0 ;
+                    {
+                        // "data" format is UTF16, so 2 bytes = one character
+                        // wxChar size depends on platform, so just clear last 2 bytes
+                        ((char*)data)[byteCount]   = 0;
+                        ((char*)data)[byteCount+1] = 0;
+                    }
                 }
                 else
                 {
@@ -192,12 +197,12 @@ void wxClipboard::Clear()
 
 bool wxClipboard::Flush()
 {
-    return FALSE;
+    return false;
 }
 
 bool wxClipboard::Open()
 {
-    wxCHECK_MSG( !m_open, FALSE, wxT("clipboard already open") );
+    wxCHECK_MSG( !m_open, false, wxT("clipboard already open") );
     m_open = true ;
     return true ;
 }
@@ -209,9 +214,9 @@ bool wxClipboard::IsOpened() const
 
 bool wxClipboard::SetData( wxDataObject *data )
 {
-    wxCHECK_MSG( m_open, FALSE, wxT("clipboard not open") );
+    wxCHECK_MSG( m_open, false, wxT("clipboard not open") );
 
-    wxCHECK_MSG( data, FALSE, wxT("data is invalid") );
+    wxCHECK_MSG( data, false, wxT("data is invalid") );
 
     Clear();
     // as we can only store one wxDataObject, this is the same in this
@@ -221,9 +226,9 @@ bool wxClipboard::SetData( wxDataObject *data )
 
 bool wxClipboard::AddData( wxDataObject *data )
 {
-    wxCHECK_MSG( m_open, FALSE, wxT("clipboard not open") );
+    wxCHECK_MSG( m_open, false, wxT("clipboard not open") );
 
-    wxCHECK_MSG( data, FALSE, wxT("data is invalid") );
+    wxCHECK_MSG( data, false, wxT("data is invalid") );
 
     /* we can only store one wxDataObject */
     Clear();
@@ -243,7 +248,9 @@ bool wxClipboard::AddData( wxDataObject *data )
         size_t sz = data->GetDataSize( array[i] ) ;
         void* buf = malloc( sz + 1 ) ;
         if ( buf )
-        {        
+        {
+            // empty the buffer because in some case GetDataHere does not fill buf
+            memset(buf, 0, sz+1);
             data->GetDataHere( array[i] , buf ) ;
             OSType mactype = 0 ;
             switch ( array[i].GetType() )
@@ -286,23 +293,23 @@ void wxClipboard::Close()
     wxCHECK_RET( m_open, wxT("clipboard not open") );
 
     m_open = false ;
-    
- 	// Get rid of cached object.  If this is not done copying from another application will
- 	// only work once
+
+    // Get rid of cached object.  If this is not done copying from another application will
+    // only work once
     if (m_data)
     {
         delete m_data;
         m_data = (wxDataObject*) NULL;
-    }    
-	    
+    }
+
 }
 
 bool wxClipboard::IsSupported( const wxDataFormat &dataFormat )
 {
-  if ( m_data )
-  {
-    return m_data->IsSupported( dataFormat ) ;
-  }
+    if ( m_data )
+    {
+        return m_data->IsSupported( dataFormat ) ;
+    }
 #if TARGET_CARBON
     OSStatus err = noErr;
     ScrapRef scrapRef;
@@ -317,11 +324,11 @@ bool wxClipboard::IsSupported( const wxDataFormat &dataFormat )
         {
             if (( err = GetScrapFlavorSize( scrapRef, dataFormat.GetFormatId(), &byteCount )) == noErr)
             {
-                return TRUE ;
+                return true ;
             }
         }
     }
-    return FALSE;
+    return false;
 
 #else
     long offset ;
@@ -337,7 +344,7 @@ bool wxClipboard::IsSupported( const wxDataFormat &dataFormat )
 
 bool wxClipboard::GetData( wxDataObject& data )
 {
-    wxCHECK_MSG( m_open, FALSE, wxT("clipboard not open") );
+    wxCHECK_MSG( m_open, false, wxT("clipboard not open") );
 
     size_t formatcount = data.GetFormatCount() + 1 ;
     wxDataFormat *array = new wxDataFormat[ formatcount  ];
@@ -380,6 +387,7 @@ bool wxClipboard::GetData( wxDataObject& data )
           switch ( format.GetType() )
           {
               case wxDF_TEXT :
+              case wxDF_UNICODETEXT:
               case wxDF_OEMTEXT :
               case wxDF_BITMAP :
               case wxDF_METAFILE :
