@@ -4,9 +4,9 @@
 // Author:      Stefan Csomor
 // Modified by:
 // Created:     01/02/97
-// RCS-ID:      $Id: dc.cpp,v 1.112 2005/04/11 18:42:11 SC Exp $
+// RCS-ID:      $Id: dc.cpp,v 1.117 2005/08/08 21:46:31 VZ Exp $
 // Copyright:   (c) Stefan Csomor
-// Licence:       wxWindows licence
+// Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
 #if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
@@ -26,19 +26,22 @@
 #include "wx/image.h"
 #include "wx/log.h"
 
-#if __MSL__ >= 0x6000
-namespace std {}
-using namespace std ;
+#ifdef __MSL__
+    #if __MSL__ >= 0x6000
+        namespace std {}
+        using namespace std ;
+    #endif
 #endif
 
 #include "wx/mac/private.h"
+#ifndef __DARWIN__
 #include <ATSUnicode.h>
 #include <TextCommon.h>
 #include <TextEncodingConverter.h>
-#if !USE_SHARED_LIBRARY
-IMPLEMENT_ABSTRACT_CLASS(wxDC, wxObject)
 #endif
 
+IMPLEMENT_ABSTRACT_CLASS(wxDC, wxObject)
+
 //-----------------------------------------------------------------------------
 // constants
 //-----------------------------------------------------------------------------
@@ -366,7 +369,7 @@ void wxDC::DoDrawBitmap( const wxBitmap &bmp, wxCoord x, wxCoord y, bool useMask
      PixMapHandle bmappixels ;
      // Set foreground and background colours (for bitmaps depth = 1)
      if(bmp.GetDepth() == 1)
-    {
+     {
          RGBColor fore = MAC_WXCOLORREF(m_textForegroundColour.GetPixel());
          RGBColor back = MAC_WXCOLORREF(m_textBackgroundColour.GetPixel());
          RGBForeColor(&fore);
@@ -1316,7 +1319,7 @@ void  wxDC::DoDrawRotatedText(const wxString& str, wxCoord x, wxCoord y,
     UniCharCount chars = str.Length() ;
     UniChar* ubuf = NULL ;
 #if SIZEOF_WCHAR_T == 4
-    wxMBConvUTF16BE converter ;
+    wxMBConvUTF16 converter ;
 #if wxUSE_UNICODE
     size_t unicharlen = converter.WC2MB( NULL , str.wc_str() , 0 ) ;
     ubuf = (UniChar*) malloc( unicharlen + 2 ) ;
@@ -1667,9 +1670,9 @@ void wxDC::MacInstallFont() const
         Pattern whiteColor ;
         ::BackPat(GetQDGlobalsWhite(&whiteColor));
     }
-    
+
     wxASSERT( m_font.Ok() ) ;
-    
+
 
     ::TextFont( m_font.MacGetFontNum() ) ;
     ::TextSize( (short)(m_scaleY * m_font.MacGetFontSize()) ) ;
@@ -1746,7 +1749,7 @@ void wxDC::MacInstallFont() const
         atsuTags, atsuSizes, atsuValues);
 
     wxASSERT_MSG( status == noErr , wxT("couldn't Modify ATSU style") ) ;
-    
+
 }
 
 Pattern gPatterns[] =
