@@ -4,7 +4,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     04/01/98
-// RCS-ID:      $Id: printmac.cpp,v 1.28 2005/05/10 06:26:58 SC Exp $
+// RCS-ID:      $Id: printmac.cpp,v 1.31 2005/09/01 05:52:20 SC Exp $
 // Copyright:   (c) Julian Smart
 // Licence:       wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -262,8 +262,19 @@ void wxMacCarbonPrintData::TransferTo( wxPrintDialogData* data )
     UInt32 from , to ;
     PMGetFirstPage( m_macPrintSettings , &from ) ;
     PMGetLastPage( m_macPrintSettings , &to ) ;
-    data->SetFromPage( from ) ;
-    data->SetToPage( to ) ;
+    if ( to >= 0x7FFFFFFF ) //  due to an OS Bug we don't get back kPMPrintAllPages
+    {
+        data->SetAllPages( true ) ;
+        // This means all pages, more or less
+        data->SetFromPage(1);
+        data->SetToPage(32000);
+    }
+    else
+    {
+        data->SetFromPage( from ) ;
+        data->SetToPage( to ) ;
+        data->SetAllPages( false );
+    }
 }
 
 void wxMacCarbonPrintData::TransferFrom( wxPrintDialogData* data )
@@ -272,10 +283,14 @@ void wxMacCarbonPrintData::TransferFrom( wxPrintDialogData* data )
     PMSetCopies( m_macPrintSettings , data->GetNoCopies() , false ) ;
     PMSetFirstPage( m_macPrintSettings , data->GetFromPage() , false ) ;
 
-    int toPage = data->GetToPage();
-    if (toPage < 1)
-        toPage = data->GetFromPage();
-    PMSetLastPage( m_macPrintSettings , toPage , false ) ;
+    if (data->GetAllPages() || data->GetFromPage() == 0)
+    {
+    	PMSetLastPage( m_macPrintSettings , (UInt32) kPMPrintAllPages, true ) ;
+	}
+	else
+	{
+    	PMSetLastPage( m_macPrintSettings , (UInt32) data->GetToPage() , false ) ;
+	}
 }
 
 /*
@@ -538,7 +553,7 @@ void wxMacPrintPreview::DetermineScaling(void)
     // m_previewScale = (float)((float)screenWidth/(float)printerWidth);
     // m_previewScale = m_previewScale * (float)((float)screenXRes/(float)printerXRes);
     
-    m_previewScale = 1 ;
+    m_previewScale = 1 ; 
 }
 
 #endif
