@@ -4,7 +4,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     04/01/98
-// RCS-ID:      $Id: app.cpp,v 1.232 2005/04/14 16:04:47 JS Exp $
+// RCS-ID:      $Id: app.cpp,v 1.238 2005/08/04 21:01:29 VZ Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -69,7 +69,8 @@
 #endif // broken compilers
 
 #if defined(__POCKETPC__) || defined(__SMARTPHONE__)
-#include <aygshell.h>
+    #include <ole2.h>
+    #include <aygshell.h>
 #endif
 
 #if wxUSE_OLE
@@ -86,12 +87,27 @@
 #include "wx/msw/wince/missing.h"
 #endif
 
-// For DLLVER_PLATFORM_WINDOWS
-#if (!defined(__MINGW32__) || wxCHECK_W32API_VERSION( 2, 0 )) && \
-    !defined(__CYGWIN__) && !defined(__DIGITALMARS__) && !defined(__WXWINCE__) && \
-    (!defined(_MSC_VER) || (_MSC_VER > 1100))
-    #include <shlwapi.h>
-#endif
+// instead of including <shlwapi.h> which is not part of the core SDK and not
+// shipped at all with other compilers, we always define the parts of it we
+// need here ourselves
+//
+// NB: DLLVER_PLATFORM_WINDOWS will be defined if shlwapi.h had been somehow
+//     included already
+#ifndef DLLVER_PLATFORM_WINDOWS
+    // hopefully we don't need to change packing as DWORDs should be already
+    // correctly aligned
+    struct DLLVERSIONINFO
+    {
+        DWORD cbSize;
+        DWORD dwMajorVersion;                   // Major version
+        DWORD dwMinorVersion;                   // Minor version
+        DWORD dwBuildNumber;                    // Build number
+        DWORD dwPlatformID;                     // DLLVER_PLATFORM_*
+    };
+
+    typedef HRESULT (CALLBACK* DLLGETVERSIONPROC)(DLLVERSIONINFO *);
+#endif // defined(DLLVERSIONINFO)
+
 
 // ---------------------------------------------------------------------------
 // global variables
@@ -280,27 +296,6 @@ bool wxApp::Initialize(int& argc, wxChar **argv)
     }
 #endif
 
-    // the first thing to do is to check if we're trying to run an Unicode
-    // program under Win9x w/o MSLU emulation layer - if so, abort right now
-    // as it has no chance to work
-#if wxUSE_UNICODE && !wxUSE_UNICODE_MSLU
-    if ( wxGetOsVersion() != wxWINDOWS_NT && wxGetOsVersion() != wxWINDOWS_CE && wxGetOsVersion() != wxWINDOWS_SMARTPHONE && wxGetOsVersion() != wxWINDOWS_POCKETPC )
-    {
-        // note that we can use MessageBoxW() as it's implemented even under
-        // Win9x - OTOH, we can't use wxGetTranslation() because the file APIs
-        // used by wxLocale are not
-        ::MessageBox
-        (
-         NULL,
-         _T("This program uses Unicode and requires Windows NT/2000/XP/CE.\nProgram aborted."),
-         _T("wxWidgets Fatal Error"),
-         MB_ICONERROR | MB_OK
-        );
-
-        return false;
-    }
-#endif // wxUSE_UNICODE && !wxUSE_UNICODE_MSLU
-
 #if defined(__WIN95__) && !defined(__WXMICROWIN__)
     InitCommonControls();
 #endif // __WIN95__
@@ -313,10 +308,6 @@ bool wxApp::Initialize(int& argc, wxChar **argv)
 
     RegisterWindowClasses();
 
-#if wxUSE_PENWINDOWS
-    wxRegisterPenWin();
-#endif
-
     wxWinHandleHash = new wxWinHashTable(wxKEY_INTEGER, 100);
 
 #if !defined(__WXMICROWIN__) && !defined(__WXWINCE__)
@@ -482,10 +473,6 @@ void wxApp::CleanUp()
     wxSetKeyboardHook(false);
 #endif
 
-#if wxUSE_PENWINDOWS
-    wxCleanUpPenWin();
-#endif
-
     wxOleUninitialize();
 
     // for an EXE the classes are unregistered when it terminates but DLL may
@@ -612,18 +599,7 @@ int wxApp::GetComCtl32Version()
         // if so, then we can check for the version
         if ( dllComCtl32.IsLoaded() )
         {
-#ifndef DLLVER_PLATFORM_WINDOWS
-			typedef struct _DllVersionInfo
-			{
-				DWORD cbSize;
-				DWORD dwMajorVersion;                   // Major version
-				DWORD dwMinorVersion;                   // Minor version
-				DWORD dwBuildNumber;                    // Build number
-				DWORD dwPlatformID;                     // DLLVER_PLATFORM_*
-			} DLLVERSIONINFO;
-			typedef HRESULT (CALLBACK* DLLGETVERSIONPROC)(DLLVERSIONINFO *);
-#endif
-            // try to use DllGetVersion() if available in _headers_
+            // now check if the function is available during run-time
             wxDYNLIB_FUNCTION( DLLGETVERSIONPROC, DllGetVersion, dllComCtl32 );
             if ( pfnDllGetVersion )
             {
