@@ -4,7 +4,7 @@
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     11.06.98
-// RCS-ID:      $Id: notebook.cpp,v 1.155 2005/05/30 11:23:27 JS Exp $
+// RCS-ID:      $Id: notebook.cpp,v 1.159 2005/08/06 01:11:11 VZ Exp $
 // Copyright:   (c) 1998 Vadim Zeitlin <zeitlin@dptmaths.ens-cachan.fr>
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -93,6 +93,14 @@
 // the pointer to standard spin button wnd proc
 static WXFARPROC gs_wndprocNotebookSpinBtn = (WXFARPROC)NULL;
 
+// the pointer to standard tab control wnd proc
+static WXFARPROC gs_wndprocNotebook = (WXFARPROC)NULL; 
+
+LRESULT APIENTRY _EXPORT wxNotebookWndProc(HWND hwnd,
+                                           UINT message,
+                                           WPARAM wParam,
+                                           LPARAM lParam);
+
 #endif // USE_NOTEBOOK_ANTIFLICKER
 
 // ----------------------------------------------------------------------------
@@ -285,6 +293,7 @@ bool wxNotebook::Create(wxWindow *parent,
 
     LPCTSTR className = WC_TABCONTROL;
 
+#if USE_NOTEBOOK_ANTIFLICKER
     // SysTabCtl32 class has natively CS_HREDRAW and CS_VREDRAW enabled and it
     // causes horrible flicker when resizing notebook, so get rid of it by
     // using a class without these styles (but otherwise identical to it)
@@ -296,11 +305,14 @@ bool wxNotebook::Create(wxWindow *parent,
             // get a copy of standard class and modify it
             WNDCLASS wc;
 
-            if ( ::GetClassInfo(::GetModuleHandle(NULL), WC_TABCONTROL, &wc) )
+            if ( ::GetClassInfo(NULL, WC_TABCONTROL, &wc) )
             {
+                gs_wndprocNotebook =
+                    wx_reinterpret_cast(WXFARPROC, wc.lpfnWndProc);
                 wc.lpszClassName = wxT("_wx_SysTabCtl32");
                 wc.style &= ~(CS_HREDRAW | CS_VREDRAW);
-
+                wc.hInstance = wxGetInstance();
+                wc.lpfnWndProc = wxNotebookWndProc;
                 s_clsNotebook.Register(wc);
             }
             else
@@ -318,6 +330,7 @@ bool wxNotebook::Create(wxWindow *parent,
             className = s_clsNotebook.GetName().c_str();
         }
     }
+#endif // USE_NOTEBOOK_ANTIFLICKER
 
     if ( !CreateControl(parent, id, pos, size, style | wxTAB_TRAVERSAL,
                         wxDefaultValidator, name) )
@@ -332,6 +345,11 @@ bool wxNotebook::Create(wxWindow *parent,
     {
         SetBackgroundColour(GetThemeBackgroundColour());
     }
+    else // use themed background by default
+    {
+        // create backing store
+        UpdateBgBrush();
+    }
 #endif // wxUSE_UXTHEME
 
     // Undocumented hack to get flat notebook style
@@ -789,6 +807,16 @@ LRESULT APIENTRY _EXPORT wxNotebookSpinBtnWndProc(HWND hwnd,
                             hwnd, message, wParam, lParam);
 }
 
+LRESULT APIENTRY _EXPORT wxNotebookWndProc(HWND hwnd,
+                                           UINT message,
+                                           WPARAM wParam,
+                                           LPARAM lParam)
+{
+    return ::CallWindowProc(CASTWNDPROC gs_wndprocNotebook,
+                            hwnd, message, wParam, lParam);
+}
+
+ 
 
 void wxNotebook::OnEraseBackground(wxEraseEvent& WXUNUSED(event))
 {
@@ -918,7 +946,7 @@ void wxNotebook::OnSize(wxSizeEvent& event)
         RefreshRect(wxRect(0, rc.top, rc.left, height), false);
         RefreshRect(wxRect(0, rc.bottom, widthNbook, heightNbook - rc.bottom),
                     false);
-        RefreshRect(wxRect(rc.right, rc.top, widthNbook - rc.bottom, height),
+        RefreshRect(wxRect(rc.right, rc.top, widthNbook - rc.right, height),
                     false);
     }
 
@@ -967,7 +995,7 @@ void wxNotebook::OnSelChange(wxNotebookEvent& event)
       {
         wxNotebookPage *pPage = m_pages[sel];
         pPage->Show(true);
-        
+
         // As per bug report:
         // http://sourceforge.net/tracker/index.php?func=detail&aid=1150659&group_id=9863&atid=109863,
         // we should not set the page focus (and thereby the focus for
@@ -1102,17 +1130,17 @@ bool wxNotebook::DoDrawBackground(WXHDC hDC, wxWindow *child)
     if ( child )
         ::MapWindowPoints(GetHwnd(), GetHwndOf(child), (POINT *)&rc, 2);
 
-
-    // apparently DrawThemeBackground() modifies the rect passed to it and if we
-    // don't do these adjustments, there are some drawing artifacts which are
-    // only visible with some non default themes; so modify the rect here using
-    // the magic numbers below so that it still paints the correct area
-    rc.left   -= 2;
-    rc.top    -= 2;
-    rc.right  += 4;
-    rc.bottom += 5;
-
-
+    // we have the content area (page size), but we need to draw all of the
+    // background for it to be aligned correctly
+    wxUxThemeEngine::Get()->GetThemeBackgroundExtent
+                            (
+                                theme,
+                                (HDC) hDC,
+                                9 /* TABP_PANE */,
+                                0,
+                                &rc,
+                                &rc
+                            );
     wxUxThemeEngine::Get()->DrawThemeBackground
                             (
                                 theme,
