@@ -5,7 +5,7 @@
 // Modified by: Wlodzimiez ABX Skiba 2003/2004 Unicode support
 //              Ron Lee
 // Created:     7.9.93
-// RCS-ID:      $Id: texutils.cpp,v 1.30 2005/01/10 17:21:16 ABX Exp $
+// RCS-ID:      $Id: texutils.cpp,v 1.32 2005/08/23 23:19:20 MR Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -1631,7 +1631,7 @@ void InitialiseColourTable(void)
 
 void Tex2RTFYield(bool force)
 {
-#ifdef __WXMSW__
+#ifdef __WINDOWS__
     static int yieldCount = 0;
 
     if (isSync)
@@ -1646,6 +1646,8 @@ void Tex2RTFYield(bool force)
         yieldCount = 10;
     }
     yieldCount --;
+#else
+    wxUnusedVar(force);
 #endif
 }
 
@@ -1720,7 +1722,6 @@ wxChar *ConvertCase(wxChar *s)
   return buf;
 }
 
-#if !WXWIN_COMPATIBILITY_2
 // if substring is true, search for str1 in str2
 bool StringMatch(const wxChar *str1, const wxChar *str2, bool subString,
                  bool exact)
@@ -1740,4 +1741,3 @@ bool StringMatch(const wxChar *str1, const wxChar *str2, bool subString,
       return exact ? wxString(str2).Cmp(str1) == 0 :
                      wxString(str2).CmpNoCase(str1) == 0;
 }
-#endif
